# Parsee PDF Reader

This PDF reader was designed to overcome the common problems when trying to extract tables from PDFs.

We started initially with a focus on financial/numeric tables, so this is where this PDF reader works best for.

## Installation

Recommended install with poetry: https://python-poetry.org/docs/

Alternatively: pip install parsee-pdf-reader

## PRE-RELEASE PUBLIC VERSION -> big changes to repo in coming days (Feb 2024), recommended to wait for public relase (end of Feb 2024)